RUSBoostClassifier
==================================================

.. currentmodule:: imblearn.ensemble

.. autoclass:: RUSBoostClassifier

   

   
   .. rubric:: Methods

   .. autosummary::
   
      
      
        ~RUSBoostClassifier.decision_function
      
      
        ~RUSBoostClassifier.fit
      
      
        ~RUSBoostClassifier.get_metadata_routing
      
      
        ~RUSBoostClassifier.get_params
      
      
        ~RUSBoostClassifier.predict
      
      
        ~RUSBoostClassifier.predict_log_proba
      
      
        ~RUSBoostClassifier.predict_proba
      
      
        ~RUSBoostClassifier.score
      
      
        ~RUSBoostClassifier.set_fit_request
      
      
        ~RUSBoostClassifier.set_params
      
      
        ~RUSBoostClassifier.set_score_request
      
      
        ~RUSBoostClassifier.staged_decision_function
      
      
        ~RUSBoostClassifier.staged_predict
      
      
        ~RUSBoostClassifier.staged_predict_proba
      
      
        ~RUSBoostClassifier.staged_score
      
   
   

.. include:: imblearn.ensemble.RUSBoostClassifier.examples

.. raw:: html

    <div style='clear:both'></div>